@@ -95,7 +95,8 @@ _service_endpoints_template = {
     'mediaconvert': '{proto}://{host}:4634',
     'resourcegroupstaggingapi':'{proto}://{host}:4635',
     'resource-groups': '{proto}://{host}:4636',
-    'efs': '{proto}://{host}:4637'
+    'efs': '{proto}://{host}:4637',
+    'backup': '{proto}://{host}:4638'
 }
 
 # TODO remove service port mapping above entirely
